@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.video.transcoder_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -137,7 +148,7 @@ class TranscoderServiceAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -173,9 +184,9 @@ class TranscoderServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, TranscoderServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the transcoder service client.
@@ -219,12 +230,12 @@ class TranscoderServiceAsyncClient:
 
     async def create_job(
         self,
-        request: Union[services.CreateJobRequest, dict] = None,
+        request: Optional[Union[services.CreateJobRequest, dict]] = None,
         *,
-        parent: str = None,
-        job: resources.Job = None,
+        parent: Optional[str] = None,
+        job: Optional[resources.Job] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Job:
         r"""Creates a job in the specified region.
@@ -260,9 +271,8 @@ class TranscoderServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.video.transcoder_v1.types.CreateJobRequest, dict]):
-                The request object. Request message for
-                `TranscoderService.CreateJob`.
+            request (Optional[Union[google.cloud.video.transcoder_v1.types.CreateJobRequest, dict]]):
+                The request object. Request message for ``TranscoderService.CreateJob``.
             parent (:class:`str`):
                 Required. The parent location to create and process this
                 job. Format: ``projects/{project}/locations/{location}``
@@ -333,11 +343,11 @@ class TranscoderServiceAsyncClient:
 
     async def list_jobs(
         self,
-        request: Union[services.ListJobsRequest, dict] = None,
+        request: Optional[Union[services.ListJobsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListJobsAsyncPager:
         r"""Lists jobs in the specified region.
@@ -370,10 +380,10 @@ class TranscoderServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.video.transcoder_v1.types.ListJobsRequest, dict]):
-                The request object. Request message for
-                `TranscoderService.ListJobs`. The parent location from
-                which to retrieve the collection of jobs.
+            request (Optional[Union[google.cloud.video.transcoder_v1.types.ListJobsRequest, dict]]):
+                The request object. Request message for ``TranscoderService.ListJobs``. The
+                parent location from which to retrieve the collection of
+                jobs.
             parent (:class:`str`):
                 Required. Format:
                 ``projects/{project}/locations/{location}``
@@ -448,11 +458,11 @@ class TranscoderServiceAsyncClient:
 
     async def get_job(
         self,
-        request: Union[services.GetJobRequest, dict] = None,
+        request: Optional[Union[services.GetJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Job:
         r"""Returns the job data.
@@ -484,9 +494,8 @@ class TranscoderServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.video.transcoder_v1.types.GetJobRequest, dict]):
-                The request object. Request message for
-                `TranscoderService.GetJob`.
+            request (Optional[Union[google.cloud.video.transcoder_v1.types.GetJobRequest, dict]]):
+                The request object. Request message for ``TranscoderService.GetJob``.
             name (:class:`str`):
                 Required. The name of the job to retrieve. Format:
                 ``projects/{project}/locations/{location}/jobs/{job}``
@@ -548,11 +557,11 @@ class TranscoderServiceAsyncClient:
 
     async def delete_job(
         self,
-        request: Union[services.DeleteJobRequest, dict] = None,
+        request: Optional[Union[services.DeleteJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a job.
@@ -581,9 +590,8 @@ class TranscoderServiceAsyncClient:
                 await client.delete_job(request=request)
 
         Args:
-            request (Union[google.cloud.video.transcoder_v1.types.DeleteJobRequest, dict]):
-                The request object. Request message for
-                `TranscoderService.DeleteJob`.
+            request (Optional[Union[google.cloud.video.transcoder_v1.types.DeleteJobRequest, dict]]):
+                The request object. Request message for ``TranscoderService.DeleteJob``.
             name (:class:`str`):
                 Required. The name of the job to delete. Format:
                 ``projects/{project}/locations/{location}/jobs/{job}``
@@ -638,13 +646,13 @@ class TranscoderServiceAsyncClient:
 
     async def create_job_template(
         self,
-        request: Union[services.CreateJobTemplateRequest, dict] = None,
+        request: Optional[Union[services.CreateJobTemplateRequest, dict]] = None,
         *,
-        parent: str = None,
-        job_template: resources.JobTemplate = None,
-        job_template_id: str = None,
+        parent: Optional[str] = None,
+        job_template: Optional[resources.JobTemplate] = None,
+        job_template_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.JobTemplate:
         r"""Creates a job template in the specified region.
@@ -677,9 +685,9 @@ class TranscoderServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.video.transcoder_v1.types.CreateJobTemplateRequest, dict]):
+            request (Optional[Union[google.cloud.video.transcoder_v1.types.CreateJobTemplateRequest, dict]]):
                 The request object. Request message for
-                `TranscoderService.CreateJobTemplate`.
+                ``TranscoderService.CreateJobTemplate``.
             parent (:class:`str`):
                 Required. The parent location to create this job
                 template. Format:
@@ -765,11 +773,11 @@ class TranscoderServiceAsyncClient:
 
     async def list_job_templates(
         self,
-        request: Union[services.ListJobTemplatesRequest, dict] = None,
+        request: Optional[Union[services.ListJobTemplatesRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListJobTemplatesAsyncPager:
         r"""Lists job templates in the specified region.
@@ -802,9 +810,9 @@ class TranscoderServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.video.transcoder_v1.types.ListJobTemplatesRequest, dict]):
+            request (Optional[Union[google.cloud.video.transcoder_v1.types.ListJobTemplatesRequest, dict]]):
                 The request object. Request message for
-                `TranscoderService.ListJobTemplates`.
+                ``TranscoderService.ListJobTemplates``.
             parent (:class:`str`):
                 Required. The parent location from which to retrieve the
                 collection of job templates. Format:
@@ -880,11 +888,11 @@ class TranscoderServiceAsyncClient:
 
     async def get_job_template(
         self,
-        request: Union[services.GetJobTemplateRequest, dict] = None,
+        request: Optional[Union[services.GetJobTemplateRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.JobTemplate:
         r"""Returns the job template data.
@@ -916,9 +924,9 @@ class TranscoderServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.video.transcoder_v1.types.GetJobTemplateRequest, dict]):
+            request (Optional[Union[google.cloud.video.transcoder_v1.types.GetJobTemplateRequest, dict]]):
                 The request object. Request message for
-                `TranscoderService.GetJobTemplate`.
+                ``TranscoderService.GetJobTemplate``.
             name (:class:`str`):
                 Required. The name of the job template to retrieve.
                 Format:
@@ -981,11 +989,11 @@ class TranscoderServiceAsyncClient:
 
     async def delete_job_template(
         self,
-        request: Union[services.DeleteJobTemplateRequest, dict] = None,
+        request: Optional[Union[services.DeleteJobTemplateRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a job template.
@@ -1014,9 +1022,9 @@ class TranscoderServiceAsyncClient:
                 await client.delete_job_template(request=request)
 
         Args:
-            request (Union[google.cloud.video.transcoder_v1.types.DeleteJobTemplateRequest, dict]):
+            request (Optional[Union[google.cloud.video.transcoder_v1.types.DeleteJobTemplateRequest, dict]]):
                 The request object. Request message for
-                `TranscoderService.DeleteJobTemplate`.
+                ``TranscoderService.DeleteJobTemplate``.
             name (:class:`str`):
                 Required. The name of the job template to delete.
                 ``projects/{project}/locations/{location}/jobTemplates/{job_template}``
@@ -1076,14 +1084,9 @@ class TranscoderServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-video-transcoder",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("TranscoderServiceAsyncClient",)
